@@ -8,7 +8,7 @@
 //! |Github Repo Secret|CARGO_TOKEN|Token issued for your user by crates.io|[How-To](https://doc.rust-lang.org/cargo/reference/publishing.html#before-your-first-publish)|
 //! |Github Repo Secret|GH_TOKEN|A GitHub PAT|[How-To](https://docs.github.com/en/github/authenticating-to-github/creating-a-personal-access-token)|
 
-#![doc(html_root_url = "https://docs.rs/happi/0.0.2")]
+#![doc(html_root_url = "https://docs.rs/happi/0.0.4")]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 // #![feature(doc_cfg)] // for local docs
 #![warn(missing_copy_implementations)]
@@ -18,6 +18,9 @@
 #![deny(missing_docs)]
 #![forbid(unsafe_code)]
 
+use happi_derive::foo;
+
 /// TODO
+#[foo]
 #[derive(Clone, Copy, Debug)]
 pub struct Todo;
